thorns
======

*Description Spike analysis software*


:Name: thorns
:Author: Marek Rudnicki
:Email: marekrud@gmail.com
:URL: https://github.com/mrkrd/thorns
:License: GNU General Public License v3 or later (GPLv3+)


Installation
------------

Developer::

  python setup.py develop --user


Administrator::

  python setup.py install


User::

  python setup.py install --user
